package WebGUI::i18n::Spanish::Macro_PickLanguage;
use utf8;
our $I18N = {
  'delete' => {
    'lastUpdated' => '1257424854',
    'message' => 'Volver al Idioma del Perfil.'
  },
  'delete_label' => {
    'lastUpdated' => '1257424880',
    'message' => 'La etiqueta para el enlace que permite regresar al idioma indicado en el Perfil de Usuario.'
  },
  'delete_url' => {
    'lastUpdated' => '1257424903',
    'message' => 'El URL que elimina el Idioma temporal para la sesión.'
  },
  'lang_loop' => {
    'lastUpdated' => '1257424917',
    'message' => 'Un ciclo que itera sobre los Idiomas instalados.'
  },
  'language_isCurrent' => {
    'lastUpdated' => '1276813202',
    'message' => 'Un condicional que indica si el idioma corresponde al idioma actual.'
  },
  'language_lang' => {
    'lastUpdated' => '1257424939',
    'message' => 'El nombre del Idioma en ese idioma.'
  },
  'language_langAbbr' => {
    'lastUpdated' => '1257424968',
    'message' => 'El código estándar para el idioma, e.g. "en", "es", "fr", "de".'
  },
  'language_langAbbrLoc' => {
    'lastUpdated' => '1257424985',
    'message' => 'La etiqueta estándar abreviada para el idioma.'
  },
  'language_langEng' => {
    'lastUpdated' => '1257424994',
    'message' => 'El nombre del Idioma en inglés.'
  },
  'language_url' => {
    'lastUpdated' => '1257425012',
    'message' => 'El URL que establece el Idioma de WebGUI al idioma seleccionado.'
  },
  'picklanguage title' => {
    'lastUpdated' => '1257425031',
    'message' => 'Variables de Plantilla para el Macro PickLanguage'
  }
}
;

1;
